Skip to contents

Render text on how Rapporteket deals with personal data

Usage

howWeDealWithPersonalData(..., callerPkg = NULL)

Arguments

...

Further arguments, currently not used

callerPkg

Character string naming the package this function was called from. The value is used to display the current version of the R package representing the registry at Rapporteket.

Value

fragment html info text