Title on the top left of the app, including the logo and memory usage
Source:R/memoryDisplay.R
memoryTitle.RdTitle on the top left of the app, including the logo and memory usage
Examples
app_ui <- function() {
shiny::navbarPage(
title = memoryTitle("My App")
)
}